@@ -103,6 +103,7 @@ TENTACLES_PATH = "tentacles"
 DEFAULT_BOT_PATH = CURRENT_DIR_PATH
 TENTACLES_BACKTESTING_PATH = "Backtesting"
 TENTACLES_EVALUATOR_PATH = "Evaluator"
+TENTACLES_META_PATH = "Meta"
 TENTACLES_PROFILES_PATH = "profiles"
 TENTACLES_INTERFACES_PATH = "Interfaces"
 TENTACLES_NOTIFIERS_PATH = "Notifiers"
@@ -120,6 +121,7 @@ TENTACLES_BACKTESTING_THIRD_LEVEL_EXCHANGES_PATH = "exchanges"
 TENTACLES_BACKTESTING_THIRD_LEVEL_SOCIAL_PATH = "social"
 TENTACLES_EVALUATOR_REALTIME_PATH = "RealTime"
 TENTACLES_EVALUATOR_TA_PATH = "TA"
+TENTACLES_EVALUATOR_SCRIPTED_PATH = "Scripted"
 TENTACLES_EVALUATOR_SOCIAL_PATH = "Social"
 TENTACLES_EVALUATOR_STRATEGIES_PATH = "Strategies"
 TENTACLES_EVALUATOR_UTIL_PATH = "Util"
@@ -127,6 +129,7 @@ TENTACLES_TRADING_MODE_PATH = "Mode"
 TENTACLES_TRADING_SUPERVISOR_PATH = "Supervisor"
 TENTACLES_TRADING_EXCHANGE_PATH = "Exchange"
 TENTACLES_WEBSOCKETS_FEEDS_PATH = "feeds"
+TENTACLES_KEYWORDS_PATH = "Keywords"
 
 # Tentacle installation context
 TENTACLE_INSTALLATION_CONTEXT_OCTOBOT_VERSION = "octobot_version"
@@ -175,9 +178,13 @@ TENTACLES_FOLDERS_ARCH = {
         TENTACLES_EVALUATOR_REALTIME_PATH,
         TENTACLES_EVALUATOR_SOCIAL_PATH,
         TENTACLES_EVALUATOR_TA_PATH,
+        TENTACLES_EVALUATOR_SCRIPTED_PATH,
         TENTACLES_EVALUATOR_STRATEGIES_PATH,
         TENTACLES_EVALUATOR_UTIL_PATH
     ],
+    TENTACLES_META_PATH: [
+        TENTACLES_KEYWORDS_PATH
+    ],
     TENTACLES_SERVICES_PATH: [
         TENTACLES_INTERFACES_PATH,
         TENTACLES_NOTIFIERS_PATH,
@@ -201,6 +208,7 @@ TENTACLE_MODULE_FOLDERS = {
 TENTACLE_TYPES = [
     TENTACLES_BACKTESTING_PATH,
     TENTACLES_EVALUATOR_PATH,
+    TENTACLES_META_PATH,
     TENTACLES_SERVICES_PATH,
     TENTACLES_TRADING_PATH
 ]
