@@ -14,7 +14,9 @@
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
 import os
-import os.path as path
+
+import aiofiles
+import yaml
 
 import octobot_tentacles_manager.exporters.artifact_exporter as artifact_exporter
 import octobot_tentacles_manager.models as models
@@ -30,21 +32,28 @@ class TentaclePackageExporter(artifact_exporter.ArtifactExporter):
                  output_dir: str = constants.DEFAULT_EXPORT_DIR,
                  should_cythonize: bool = False,
                  should_zip: bool = False,
-                 with_dev_mode: bool = False):
+                 with_dev_mode: bool = False,
+                 metadata_file: str = None,
+                 use_package_as_file_name: bool = False):
         output_dir = TentaclePackageExporter.include_output_dir_in_package_name_if_any(artifact, output_dir)
         super().__init__(artifact,
                          tentacles_folder=tentacles_folder,
                          output_dir=output_dir,
                          should_cythonize=should_cythonize,
                          should_zip=should_zip,
-                         with_dev_mode=with_dev_mode)
+                         with_dev_mode=with_dev_mode,
+                         use_package_as_file_name=use_package_as_file_name)
         self.exported_tentacles_package: str = exported_tentacles_package
         self.should_cleanup_working_folder: bool = True
+        self.imported_metadata_file: str = metadata_file
 
         self.tentacles_filter: util.TentacleFilter = None
         self.tentacles_white_list: list = []
         self.tentacles = []
 
+        if self.should_zip:
+            self.working_folder = os.path.join(self.working_folder, constants.TENTACLES_ARCHIVE_ROOT)
+
     async def prepare_export(self):
         if not self.with_dev_mode or self.exported_tentacles_package is not None:
             self.tentacles = util.load_tentacle_with_metadata(self.tentacles_folder)
@@ -55,7 +64,12 @@ class TentaclePackageExporter(artifact_exporter.ArtifactExporter):
                 package_filter=self.exported_tentacles_package
             )
 
+        # filter tentacles
         self.tentacles_filter = util.TentacleFilter(self.tentacles, self.tentacles_white_list)
+
+        # set white list tentacles as TentaclePackage.artifacts
+        self.artifact.artifacts = self.tentacles_white_list
+
         if self.should_zip:
             self.copy_directory_content_to_temporary_dir(self.tentacles_folder,
                                                          ignore=self.tentacles_filter.should_ignore)
@@ -76,3 +90,17 @@ class TentaclePackageExporter(artifact_exporter.ArtifactExporter):
 
     async def after_export(self):
         pass
+
+    def get_metadata_file_path(self) -> str:
+        """
+        :return: the metadata destination file path
+        """
+        return os.path.abspath(self.output_dir)
+
+    async def get_metadata_instance(self) -> models.ArtifactMetadata:
+        metadata_instance = models.MetadataFactory(self.artifact).create_metadata_instance()
+        if self.imported_metadata_file:
+            async with aiofiles.open(os.path.join(self.imported_metadata_file), "r") as imported_metadata_file:
+                metadata_instance.original_metadata_dict = yaml.safe_load(await imported_metadata_file.read())
+            metadata_instance.load_from_dict()
+        return metadata_instance
